# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.9
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class PlatformAppearance(str, Enum):
    """
    * `DEFAULT` mode means the UI should follow device's System Settings for switching between light mode and dark mode * `LIGHT` or `DARK` mode sets the UI to the desired state regardless of System Settings 
    """

    """
    allowed enum values
    """
    DEFAULT = 'DEFAULT'
    LIGHT = 'LIGHT'
    DARK = 'DARK'

    @classmethod
    def from_json(cls, json_str: str) -> PlatformAppearance:
        """Create an instance of PlatformAppearance from a JSON string"""
        return PlatformAppearance(json.loads(json_str))


